pub struct Element {
pub certificate: Option<Vec<u8>>,
pub parsed_successfully: Option<bool>,
pub subject: Option<Vec<u8>>,
pub issuer: Option<Vec<u8>>,
pub fingerprint: Option<Vec<u8>>,
pub expiry_time: Option<i64>,
pub start_time: Option<i64>,
}Fields
certificate: Option<Vec<u8>>parsed_successfully: Option<bool>subject: Option<Vec<u8>>issuer: Option<Vec<u8>>fingerprint: Option<Vec<u8>>expiry_time: Option<i64>start_time: Option<i64>Implementations
Sourceimpl Element
impl Element
Sourcepub fn certificate(&self) -> &[u8] ⓘ
pub fn certificate(&self) -> &[u8] ⓘ
Returns the value of certificate, or the default value if certificate is unset.
Sourcepub fn parsed_successfully(&self) -> bool
pub fn parsed_successfully(&self) -> bool
Returns the value of parsed_successfully, or the default value if parsed_successfully is unset.
Sourcepub fn subject(&self) -> &[u8] ⓘ
pub fn subject(&self) -> &[u8] ⓘ
Returns the value of subject, or the default value if subject is unset.
Sourcepub fn issuer(&self) -> &[u8] ⓘ
pub fn issuer(&self) -> &[u8] ⓘ
Returns the value of issuer, or the default value if issuer is unset.
Sourcepub fn fingerprint(&self) -> &[u8] ⓘ
pub fn fingerprint(&self) -> &[u8] ⓘ
Returns the value of fingerprint, or the default value if fingerprint is unset.
Sourcepub fn expiry_time(&self) -> i64
pub fn expiry_time(&self) -> i64
Returns the value of expiry_time, or the default value if expiry_time is unset.
Sourcepub fn start_time(&self) -> i64
pub fn start_time(&self) -> i64
Returns the value of start_time, or the default value if start_time is unset.